@@ -176,14 +176,14 @@ areColors <- function(colvec) {
 ### @param nDatasets vector returned by \code{'processInput'}.
 ### @param verbose logical; turn on verbose printing.
 ### @param loadedIdx index of the currently loaded dataset.
-### @param dataLoaded currently loaded data matrix (may be NULL).
-### @param networkLoaded currently loaded network matrix.
+### @param dataEnv environment containing currently loaded data matrix (may be NULL).
+### @param networkEnv environment containing currently loaded network matrix.
 ###
 ### @keywords internal
 plotProps <- function(
   network, data, moduleAssignments, modules, di, ti, orderNodesBy, 
   orderSamplesBy, orderModules, datasetNames, nDatasets, verbose, loadedIdx, 
-  dataLoaded, networkLoaded
+  dataEnv, networkEnv
 ) {
   mods <- modules[[di]]
   mi <- NULL # suppresses CRAN note
@@ -211,7 +211,7 @@ plotProps <- function(
   # Calculate the network properties for all datasets required
   res <- netPropsInternal(network, data, moduleAssignments, modules, di, 
                           plotDatasets, nDatasets, datasetNames, verbose, 
-                          loadedIdx, dataLoaded, networkLoaded, TRUE)
+                          loadedIdx, dataEnv, networkEnv, TRUE)
   props <- res$props
   loadedIdx <- res$loadedIdx
   
@@ -252,14 +252,25 @@ plotProps <- function(
     }
   }
   
+  nNewSamples <- 0
   if (is.null(orderSamplesBy)) {
     sampleOrder <- NULL
   } else if (!is.na(orderSamplesBy)) {
-    orderProps <- filterInternalProps(props, orderSamplesBy, di, moduleOrder[1])
-    sampleOrder <- sampleOrderInternal(orderProps, verbose, na.rm=FALSE)
+    sampleOrderProps <- filterInternalProps(props, orderSamplesBy, di, moduleOrder[1])
+    sampleOrder <- sampleOrderInternal(sampleOrderProps, verbose, na.rm=FALSE)
     sampleOrder <- simplifyList(sampleOrder, depth=3)
+    
+    # Tack samples present in the test dataset not present in the 'orderSamplesBy'
+    # dataset -- these are important because the contribute to the calculation of
+    # the summary profiles, correlation, and network matrices!
+    testOrderProps <- filterInternalProps(props, ti, di, moduleOrder[1])
+    testSampleOrder <- sampleOrderInternal(testOrderProps, verbose, na.rm=FALSE)
+    testSampleOrder <- simplifyList(testSampleOrder, depth=3)
+    newSamples <- testSampleOrder %sub_nin% sampleOrder
+    nNewSamples <- length(newSamples)
+    sampleOrder <- c(sampleOrder, newSamples)
   } else {
-    sampleOrder <- rownames(deref(dataLoaded))
+    sampleOrder <- rownames(dataEnv$matrix)
   }
   
   # Just keep the properties we need for plotting
@@ -274,7 +285,7 @@ plotProps <- function(
   # 'test' dataset.
   #-----------------------------------------------------------------------------
   
-  na.pos.x <- which(nodeOrder %nin% colnames(deref(networkLoaded)))
+  na.pos.x <- which(nodeOrder %nin% colnames(networkEnv$matrix))
   if (length(na.pos.x) > 0) {
     presentNodes <- nodeOrder[-na.pos.x]
   } else {
@@ -285,7 +296,7 @@ plotProps <- function(
     na.pos.y <- NULL
     presentSamples <- NULL
   } else if (!is.numeric(sampleOrder)) {
-    na.pos.y <- which(sampleOrder %nin% rownames(deref(dataLoaded)))
+    na.pos.y <- which(sampleOrder %nin% rownames(dataEnv$matrix))
     if (length(na.pos.y) > 0) {
       presentSamples <- sampleOrder[-na.pos.y]
     } else {
@@ -316,6 +327,7 @@ plotProps <- function(
   return(list(
     testProps=testProps, nodeOrder=nodeOrder, moduleOrder=moduleOrder,
     sampleOrder=sampleOrder, na.pos.x=na.pos.x, na.pos.y=na.pos.y,
-    presentNodes=presentNodes, presentSamples=presentSamples
+    presentNodes=presentNodes, presentSamples=presentSamples,
+    nNewSamples=nNewSamples
   ))
 }
